from setuptools import setup

setup(name='Binomial_Gauss',
      version='1.1',
      description='Gaussian and Binomial distributions',
      packages=['Binomial_Gauss'],
      author = 'Pankaj Biradar',
      author_email = 'pankaj28988@gmail.com',
      zip_safe=False)
